@@ -1,7 +1,7 @@
 import typer
 
 import os, sys
-pwd = "/".join(__file__.split("/")[:-1]) + "/lib"
+pwd = "/".join(__file__.split("/")[:-1])
 sys.path.append(pwd)
 
 import lib.wifi as wifi
